/* ver.B.b16.02(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"ppm2r64",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b16.02(BLAZE)",
	2007,5,27,
	0,
	"ppm to r64/cr format converter ",
};

